==> mxlogging-1.0.1.tar.gz: mxlogging-1.0.1/README.md <==

## MxLogging

Un sistema de logging optimizado para una interpretación clara y una integración sencilla de mensajes. Pensado para mejorar la trazabilidad y el diagnóstico en proyectos de software.
Crea con el mismo nombre del script principal el archivo .log y además lo almacena dentro de la carpeta "logs" (si no existe la crea). 
No hay que preocuparse en nada más que de escribir el logging.

## USO de mxlogging:
- Primero importamos y llamamos a la clase:
  import mxlogging -> Importamos clase
  lgn = mxlogging.lgn() -> Llamamos clase

- Añadimos el config del logging:
  lgn.config(atributos)
  * Atributos de configuraciones:
       - time_log = False or None -> crea el archivo log con nombre: nombreScript.log
       - time_log = True -> crea el log crea el archivo log con nombre: nombreScript_fechaHora.log

- Start prepara el archivo log dentro de la carpeta logs y te añade separación start:
  lgn.start()

- Añadir mensajes en LOG:
    - lgn.t() -> Sin añadirle atributos te pone como título la ruta del script, va bien por si quieres anotar cuando cambia de un script a otro.
    - lgn.s('Mensaje Subtitulo')
    - lgn.p('Mensaje Párrafo')
    - lgn.e('Mensaje Error')

- Fin del Log, te añade separación para el final:
    - lgn.end() 


### Ejemplo de uso de mxlogging:
```
(Ejecutando script main.py)
import mxlogging
lgn = mxlogging.lgn()
lgn.config(time_log=True)
lgn.start()

lgn.t()
lgn.s('Subtitulo')
lgn.p('Parrafo')

funcion_main2() # (se llama y ejecuta función del main2.py)
   #(dentro de main2.py)
      #lgn.t()
      #lgn.s('Subtitulo 2')
      #lgn.p('Parrafo 2')

lgn.t()
lgn.e('Ejemplo Errores!')
lgn.end()
```

### Ejemplo archivo LOG creado:
```
-15-Oct-23 12:04:43 
==============================================================================
    ** START LOG: main.py **
==============================================================================

15-Oct-23 12:04:43
* Ruta script actual:
    /Users/pistatxos/Desktop/carpeta1/test/main.py
-------------------------------------------------------------------------

15-Oct-23 12:04:43 - Subtitulo
15-Oct-23 12:04:43   - Parrafo
15-Oct-23 12:04:43
* Ruta script actual:
    /Users/pistatxos/Desktop/carpeta1/test/main2.py
--------------------------------------------------------------------------

15-Oct-23 12:04:43 - Subtitulo 2
15-Oct-23 12:04:43   - Parrafo 2
15-Oct-23 12:04:43
* Ruta script actual:
    /Users/pistatxos/Desktop/carpeta1/test/main.py
-------------------------------------------------------------------------

-15-Oct-23 12:04:43 ERROR - Ejemplo rrores!
15-Oct-23 12:04:43
===============================================================================
    ** FIN LOG: main.py **
===============================================================================
``````

==> mxlogging-1.0.9.tar.gz: mxlogging-1.0.9/README.md <==

## MxLogging

Un sistema de logging optimizado para una interpretación clara y una integración sencilla de mensajes. Pensado para mejorar la trazabilidad y el diagnóstico en proyectos de software.
Crea con el mismo nombre del script principal el archivo .log y además lo almacena dentro de la carpeta "logs" (si no existe la crea). 
No hay que preocuparse en nada más que de escribir el logging.

## USO de mxlogging:
- Primero importamos y llamamos a la clase:
  import mxlogging -> Importamos clase
  lgn = mxlogging.lgn() -> Llamamos clase

- Añadimos el config del logging:
  lgn.config(atributos)
  * Atributos de configuraciones:
    - time_log
       - time_log = False or None -> crea el archivo log con nombre: nombreScript.log
       - time_log = True -> crea el log crea el archivo log con nombre: nombreScript_fechaHora.log
    - ruta_log
        - ruta_log = None -> crea el archivo en la ruta por default, dentro de una carpeta ./logs en la raiz del script que ejecuta.
        - ruta_log = "path absoluto donde guardará el archivo .log" # Nueva ruta.
    - nombre_log
        - nombre_log = None -> crea el nombre del archivo por defecto que será el nombre del script.
        - nombre_log = "nombreDelLog" # Para renombrar el log.

- Start prepara el archivo log dentro de la carpeta logs y te añade separación start:
  lgn.start()

- Añadir mensajes en LOG:
    - lgn.t() -> Sin añadirle atributos te pone como título la ruta del script, va bien por si quieres anotar cuando cambia de un script a otro.
    - lgn.s('Mensaje Subtitulo')
    - lgn.p('Mensaje Párrafo')
    - lgn.e('Mensaje Error')

- Fin del Log, te añade separación para el final:
    - lgn.end() 


### Ejemplo de uso de mxlogging:
```
(Ejecutando script main.py)
import mxlogging
lgn = mxlogging.lgn()
lgn.config(time_log=True, 
            ruta_log='/Users/Pistatxos/carpeta1/carpeta2/',
            nombre_log='nombreDelLog')
lgn.start()

lgn.t()
lgn.s('Subtitulo')
lgn.p('Parrafo')

funcion_main2() # (se llama y ejecuta función del main2.py)
   #(dentro de main2.py)
      #lgn.t()
      #lgn.s('Subtitulo 2')
      #lgn.p('Parrafo 2')

lgn.t()
lgn.e('Ejemplo Errores!')
lgn.end()
```

### Ejemplo archivo LOG creado:
```
-15-Oct-23 12:04:43 
==============================================================================
    ** START LOG: main.py **
==============================================================================
15-Oct-23 12:04:43 * Ruta script actual:
    /Users/pistatxos/Desktop/carpeta1/test/main.py
    ----------------------------------------------
15-Oct-23 12:04:43 - Subtitulo
15-Oct-23 12:04:43   - Parrafo
15-Oct-23 12:04:43 * Ruta script actual:
    /Users/pistatxos/Desktop/carpeta1/test/main2.py
    -----------------------------------------------
15-Oct-23 12:04:43 - Subtitulo 2
15-Oct-23 12:04:43   - Parrafo 2
15-Oct-23 12:04:43 * Ruta script actual:
    /Users/pistatxos/Desktop/carpeta1/test/main.py
    ----------------------------------------------
-15-Oct-23 12:04:43 ERROR - Ejemplo rrores!
15-Oct-23 12:04:43
===============================================================================
    ** FIN LOG: main.py **
===============================================================================
``````
